@@ -4,6 +4,9 @@ from .pubsub_manager import PubSubManager
 from .kombu_manager import KombuManager
 from .redis_manager import RedisManager
 from .server import Server
+from .namespace import Namespace
 
-__all__ = [Middleware, Server, BaseManager, PubSubManager, KombuManager,
-           RedisManager]
+__version__ = '1.6.0'
+
+__all__ = [__version__, Middleware, Server, BaseManager, PubSubManager,
+           KombuManager, RedisManager, Namespace]
