@@ -1,4 +1,5 @@
 import pickle
+import uuid
 
 try:
     import kombu
@@ -30,25 +31,43 @@ class KombuManager(PubSubManager):  # pragma: no cover
                 connection URLs.
     :param channel: The channel name on which the server sends and receives
                     notifications. Must be the same in all the servers.
+    :param write_only: If set ot ``True``, only initialize to emit events. The
+                       default of ``False`` initializes the class for emitting
+                       and receiving.
     """
     name = 'kombu'
 
     def __init__(self, url='amqp://guest:guest@localhost:5672//',
-                 channel='socketio'):
+                 channel='socketio', write_only=False):
         if kombu is None:
             raise RuntimeError('Kombu package is not installed '
                                '(Run "pip install kombu" in your '
                                'virtualenv).')
-        self.kombu = kombu.Connection(url)
-        self.queue = self.kombu.SimpleQueue(channel)
         super(KombuManager, self).__init__(channel=channel)
+        self.url = url
+        self.producer = self._producer()
+
+    def _connection(self):
+        return kombu.Connection(self.url)
+
+    def _exchange(self):
+        return kombu.Exchange(self.channel, type='fanout', durable=False)
+
+    def _queue(self):
+        queue_name = 'flask-socketio.' + str(uuid.uuid4())
+        return kombu.Queue(queue_name, self._exchange(),
+                           queue_arguments={'x-expires': 300000})
+
+    def _producer(self):
+        return self._connection().Producer(exchange=self._exchange())
 
     def _publish(self, data):
-        return self.queue.put(pickle.dumps(data))
+        self.producer.publish(pickle.dumps(data))
 
     def _listen(self):
-        listen_queue = self.kombu.SimpleQueue(self.channel)
-        while True:
-            message = listen_queue.get(block=True)
-            message.ack()
-            yield message.payload
+        reader_queue = self._queue()
+        with self._connection().SimpleQueue(reader_queue) as queue:
+            while True:
+                message = queue.get(block=True)
+                message.ack()
+                yield message.payload
